@@ -4,7 +4,7 @@ import IJulia
 
 const TEST_FILES = [
     "install.jl", "comm.jl", "msg.jl", "execute_request.jl", "stdio.jl",
-    "inline.jl", "completion.jl", "kernel.jl"
+    "inline.jl", "completion.jl"
 ]
 
 for file in TEST_FILES
@@ -12,11 +12,19 @@ for file in TEST_FILES
     include(file)
 end
 
+# Python is well-nigh impossible to install on 32bit
+if Sys.WORD_SIZE != 32
+    include("kernel.jl")
+else
+    @warn "Skipping the Kernel tests on 32bit"
+end
+
 @testset "Aqua.jl" begin
     # Note that Pkg and Conda are loaded lazily
     Aqua.test_all(IJulia; stale_deps=(; ignore=[:Pkg, :Conda]))
 end
 
-@testset "JET.jl" begin
-    JET.test_package(IJulia; target_defined_modules=true)
-end
+# Temporarily disabled because JET doesn't seem to play well with JSON v1
+# @testset "JET.jl" begin
+#     JET.test_package(IJulia; target_defined_modules=true)
+# end
